# OpenSearch::Client is an unofficial client for OpenSearch. 
# It is derived from Search::Elasticsearch version 7.714
# License details from the original work are contained in the
# NOTICE file distributed with this work.
#
#-----------------------------------------------------------------------
# OpenSearch::Client
#-----------------------------------------------------------------------
# Copyright 2026 Mark Dootson
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

use Test::More;

BEGIN { use_ok('OpenSearch::Client') }

my ( $e, $p, $t );

ok $e = OpenSearch::Client->new(), "new client";
ok $e->does('OpenSearch::Client::Role::Client::Direct'),
    "client does OpenSearch::Client::Role::Client::Direct";
isa_ok $t = $e->transport, 'OpenSearch::Client::Transport', "transport";
isa_ok $p = $t->cxn_pool, 'OpenSearch::Client::CxnPool::Static',
    "cxn_pool";
isa_ok $p->cxn_factory, 'OpenSearch::Client::Cxn::Factory', "cxn_factory";
isa_ok $e->logger, 'OpenSearch::Client::Logger::LogAny', "logger";

done_testing;

